@@ -1,5 +1,5 @@
 # typedload
-# Copyright (C) 2018-2021 Salvo "LtWorf" Tomaselli
+# Copyright (C) 2018-2024 Salvo "LtWorf" Tomaselli
 #
 # typedload is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -143,7 +143,6 @@ class TestAttrload(unittest.TestCase):
         assert type(load({'a': 1}, A).uuid_value) == str
         assert load({'a': 1}, A) != load({'a': 1}, A)
 
-
 class TestMangling(unittest.TestCase):
 
     def test_mangle_extra(self):
@@ -236,6 +235,18 @@ class TestAttrExceptions(unittest.TestCase):
             assert e.trace[-1].annotation[1] == 2
 
 
+    def test_needed_missing(self):
+        @attrs
+        class A:
+            a: int = attrib()
+            b: int = attrib()
+        load({'a':1, 'b': 2}, A)
+        with self.assertRaises(exceptions.TypedloadTypeError):
+            load({}, A)
+        with self.assertRaises(exceptions.TypedloadTypeError):
+            load({'a':1}, A)
+
+
 class TestAttrConverter(unittest.TestCase):
 
     def test_old_style_int_conversion_any(self):
