@@ -45,6 +45,14 @@ class TestDataclassLoad(unittest.TestCase):
         assert a.a == 12
         assert a.b == 30
 
+    def test_missing(self):
+        @dataclass
+        class A:
+            a: int
+
+        with self.assertRaises(TypeError):
+            load({}, A)
+
     def test_is_dataclass(self):
         @dataclass
         class A:
@@ -113,6 +121,15 @@ class TestDataclassUnion(unittest.TestCase):
         assert type(loader.load({'val': {'a': 1}}, C).val) == A
         assert type(loader.load({'val': {'a': '1'}}, C).val) == B
 
+
+# This class has to be defined at the top-level of the module to be visible by get_type_hints
+# when it resolves the "Node" string annotation.
+@dataclass
+class Node:
+    name: str
+    child: Optional["Node"] = None
+
+
 class TestDataclassDump(unittest.TestCase):
 
     def test_dump(self):
@@ -133,6 +150,13 @@ class TestDataclassDump(unittest.TestCase):
         assert dump(A(3)) == {'a': 3}
         assert dump(A(12), hidedefault=False) == {'a': 12, 'b': []}
 
+    def test_cyclic_dump(self):
+        assert dump(Node("foo")) == {"name": "foo"}
+        assert dump(Node("foo", child=Node("bar"))) == {
+            "name": "foo",
+            "child": {"name": "bar"},
+        }
+
 
 class TestDataclassMangle(unittest.TestCase):
 
@@ -157,7 +181,7 @@ class TestDataclassMangle(unittest.TestCase):
             value: int = field(metadata={'name': 'Value'})
         assert load({'Value': 1}, Mangle) == Mangle(1)
         assert 'Value' in dump(Mangle(1))
-        with self.assertRaises(ValueError):
+        with self.assertRaises(TypeError):
             load({'value': 1}, Mangle)
 
     def test_mangle_rename(self):
