@@ -49,7 +49,7 @@ class TestTypeddictLoad(unittest.TestCase):
             # This only works from 3.9
             return
 
-        with self.assertRaises(ValueError):
+        with self.assertRaises(TypeError):
             load({}, C)
         assert load({'val': 'a'}, C) == {'val': 'a'}
         with self.assertRaises(ValueError):
@@ -57,16 +57,16 @@ class TestTypeddictLoad(unittest.TestCase):
         assert load({'val': 'a', 'vel': 1}, C) == {'val': 'a', 'vel': 1}
         assert load({'val': 'a', 'vel': '1'}, C) == {'val': 'a', 'vel': 1}
         assert load({'val': 'a','vil': 2}, C) == {'val': 'a'}
-        with self.assertRaises(ValueError):
+        with self.assertRaises(TypeError):
             load({'val': 'a','vil': 2}, C, failonextra=True)
 
     def test_totality(self):
-        with self.assertRaises(ValueError):
+        with self.assertRaises(TypeError):
             load({}, A)
         assert load({}, B) == {}
         assert load({'val': 'a'}, B) == {'val': 'a'}
         assert load({'vel': 'q'}, B) == {}
-        with self.assertRaises(ValueError):
+        with self.assertRaises(TypeError):
             load({'vel': 'q'}, B, failonextra=True)
 
     def test_loadperson(self):
@@ -75,11 +75,11 @@ class TestTypeddictLoad(unittest.TestCase):
         assert load({'val': 3}, A) == {'val': '3'}
         assert load({'val': 3, 'vil': 4}, A) == {'val': '3'}
 
-        with self.assertRaises(ValueError):
+        with self.assertRaises(TypeError):
             o.pop('age')
             load(o, Person)
 
-        with self.assertRaises(ValueError):
+        with self.assertRaises(TypeError):
             load({'val': 3, 'vil': 4}, A, failonextra=True)
 
     def test_is_typeddict(self):
@@ -123,7 +123,7 @@ if sys.version_info.minor >= 11:
                 c: int
                 d: NotRequired[int]
 
-            with self.assertRaises(ValueError):
+            with self.assertRaises(TypeError):
                 load({}, B)
             assert load({'a': 1}, B) == {'a': 1}
             assert load({'a': 1, 'd':12}, B) == {'a': 1, 'd': 12}
