@@ -3,7 +3,7 @@ typedload
 This module is the inverse of dataloader. It converts typed
 data structures to things that json can serialize.
 """
-# Copyright (C) 2018-2023 Salvo "LtWorf" Tomaselli
+# Copyright (C) 2018-2024 Salvo "LtWorf" Tomaselli
 #
 # typedload is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -30,7 +30,7 @@ from typing import *
 import uuid
 
 from .exceptions import TypedloadValueError
-from .typechecks import is_attrs, NONETYPE
+from .typechecks import is_attrs, NONETYPE, is_literal
 
 
 __all__ = [
@@ -154,7 +154,7 @@ class Dumper:
         ]  # type: List[Tuple[Callable[[Any], bool], Callable[['Dumper', Any, Any], Any]|Callable[['Dumper', Any], Any]]]
 
         self._handlerscache = {}  # type: Dict[Type[Any], Callable[['Dumper', Any, Any], Any]]
-        self._dataclasscache = {}  # type: Dict[Type[Any], Tuple[Set[str], Dict[str, Any], Dict[str, Any]]]
+        self._dataclasscache = {}  # type: Dict[Type[Any], Tuple[Set[str], Dict[str, Any], Dict[str, Any], Dict[str, str], Set[str]]]
 
         for k, v in kwargs.items():
             setattr(self, k, v)
@@ -186,8 +186,9 @@ class Dumper:
         It is not needed to provide it, but it can enable some faster code paths.
         """
         t = type(value)
-        func = self._handlerscache.get(t)
-        if func is None:
+        try:
+            func = self._handlerscache[t]
+        except KeyError:
             index = self.index(value)
             f = self.handlers[index][1]
             # It has no type parameter, make a lambda
@@ -261,26 +262,50 @@ def _namedtupledump(d: Dumper, value, t) -> Dict[str, Any]:
 
 def _dataclassdump(d: Dumper, value, t) -> Dict[str, Any]:
     t = type(value)
-    cached = d._dataclasscache.get(t)
-    if cached is None:
+    try:
+        fields, defaults, type_hints, renames, needs_dump  = d._dataclasscache[t]
+    except KeyError:
         from dataclasses import _MISSING_TYPE as DT_MISSING_TYPE
         fields = set(value.__dataclass_fields__.keys())
         field_defaults = {k: v.default for k,v in value.__dataclass_fields__.items() if not isinstance (v.default, DT_MISSING_TYPE)}
         field_factories = {k: v.default_factory() for k,v in value.__dataclass_fields__.items() if not isinstance (v.default_factory, DT_MISSING_TYPE)}
         defaults = {**field_defaults, **field_factories} # Merge the two dictionaries
-        type_hints = get_type_hints(value)
-        d._dataclasscache[t] = (fields, defaults, type_hints)
-    else:
-        fields, defaults, type_hints = cached
+        type_hints = get_type_hints(t)
+        renames = {k: v.metadata[d.mangle_key] for k,v in value.__dataclass_fields__.items() if d.mangle_key in v.metadata}
+        # Fields to dump directly
+        needs_dump = fields.difference({
+            k for k,v in value.__dataclass_fields__.items()
+            if (v.type in d.basictypes and d.handlers[0][1] == _identitydump) or is_literal(v.type)
+        })
+
+        d._dataclasscache[t] = (fields, defaults, type_hints, renames, needs_dump)
+
+    r = value.__dict__.copy()
+    for k in fields:
+        if not d.hidedefault or k not in defaults or defaults[k] != r[k]:
+            if k in needs_dump:
+                r[k] = d.dump(r[k], type_hints[k])
+        else:
+            del r[k]
+
+    if renames:
+        renamesqueue = []
+        for f in renames:
+            if f in r:
+                renamesqueue.append((renames[f], r.pop(f)))
+        for k,v  in renamesqueue:
+            r[k] = v
 
-    r = {
-        value.__dataclass_fields__[f].metadata.get(d.mangle_key, f) : d.dump(getattr(value, f), type_hints.get(f, Any)) for f in fields
-        if not d.hidedefault or f not in defaults or defaults[f] != getattr(value, f)
-    }
     return r
 
 def _iteratordump(d: Dumper, value: Any, t: Any) -> List[Any]:
-    itertypes = getattr(t, '__args__', (Any, ))
+    if t != Any:
+        try:
+            itertypes = t.__args__
+        except AttributeError:
+            itertypes = (Any,)
+    else:
+        itertypes = (Any,)
     # list[T] or tuple[T, ...]
     if (len(itertypes) == 1) or (len(itertypes) == 2 and itertypes[1] == ...):  # type: ignore
         # This is true for lists/sets but not tuples
@@ -295,7 +320,7 @@ def _iteratordump(d: Dumper, value: Any, t: Any) -> List[Any]:
             return value.copy()
         else:
             # Create a list and return it otherwise
-            return [i for i in value]
+            return list(value)
 
     return [d.dump(i) for i in value]
 
